#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# (c) 2010 Mikael Jacobson
# 118100personsk, anvnder sig av det "frsmaks-API" som
# finns p utveckling.118100.se
import sys
from optparse import OptionParser
from HundraArtonEtthundra import HundraArtonEttHundra, HundraArtonEttHundraResult
from lxml import etree

''' Takes a HundraArtonEttHundraTelephone object and returns a formatted string ready to print '''
def format_phone_number(number):
    output = str() 
    if number.type == 'landLine':
        output = '\tTelefonnummer (fast):         '
    elif number.type == 'mobile':
        output = '\tTelefonnummer (mobiltelefon): '
    elif number.type == 'fax':
        output = '\tFaxnummer:                    '
    elif number.type == 'pbx':
        output = '\tVxel:                        '
    else:
        output = '\tTelefonnummer:                '

    output += (('+'+number.international_prefix) if number.international_prefix is not None else '') + (number.area_code if number.area_code is not None else '') + (number.local_number if number.local_number is not None else '')
    return output

''' Takes a HundraArtonEttHundraAddress object and returns a list of formatted strings '''
def format_address(address):
    output = []
    if address.street is not None:
        output.append('\tGatuadress: ' + (address.street if address.street is not None else '') + ' ' + (address.number if address.number is not None else ''))
    if address.zip is not None:
        output.append('\tPostnummer: ' + str(address.zip))
    if address.city is not None:
        output.append('\tStad:       ' + (address.city if address.city is not None else ''))
    return output

''' Takes a HundraArtonEttHundraName object and returns a formatted string '''
def format_name(name):
    output = str()
    if name.type == 'legal':
        output = '\tFretagsnamn: '
    elif name.type == 'popular':
        output = '\tPopulrnamn:  '
    elif name.type == 'tradename':
        output = '\tVarumrke:    '
    elif name.type == 'first':
        output = '\tFrnamn:      '
    elif name.type == 'middle':
        output = '\tMellannamn:   '
    elif name.type == 'last':
        output = '\tEfternamn:    '
    else:
        output = '\tNamn:         '

    output += (name.name.encode('iso-8859-1') if name.name is not None else '')
    return output

''' Takes a HundraArtonEttHundraTeleAddress object and formats it for output '''
def format_tele_address(tele_addr):
    output = str()
    if tele_addr.type == 'web':
        output = '\tHemsida: '
    elif tele_addr.type == 'email':
        output = '\tE-post:  '
    else:
        output = '\tAnnan:   '

    output += (tele_addr.name.encode('iso-8859-1') if tele_addr.name is not None else '')
    return output

''' Generalised record output function, takes a HundraArtonEttHundraData object '''
def print_record(record):
    for name in record.names:
        print(format_name(name))
    if record.person_number is not None:
        print '\tPersonnummer: ' + (record.person_number if record.person_number is not None else '')
    if record.organisation_number is not None:
        print '\tOrganisationsnummer: ' + (record.organisation_number if record.organisation_number is not None else '')
    for address in record.addresses:
        for line in format_address(address):
            print line

    for number in record.phone_numbers:
        print(format_phone_number(number))

    for tele_address in record.tele_address:
        print(format_tele_address(tele_address))


''' Main function, because every app needs one '''
def main(opts, searchstring):
    hundraarton = HundraArtonEttHundra(opts.pagesize)
    hundraarton.do_search(searchstring)

    if opts.display_raw_xml is True:
        print etree.tostring(hundraarton.xml)
    else:
        # Print persons
        if len(hundraarton.person_results) > 0:
            print '-- Privatpersoner --'
            for res in hundraarton.person_results:
                print_record(res)
                print '\n'
        elif opts.search_person is True:
            print '-- Inga privatpersoner hittades --'

if __name__ == '__main__':
    # Parse command line args
    parser = OptionParser(usage='Usage: %prog <options> <search string>')
    parser.disable_interspersed_args()
    parser.add_option('-x', '--xml', action='store_true', dest='display_raw_xml', help='Displays raw XML output', default=False)
    parser.add_option('-s', '--pagesize', type='int', dest='pagesize', help='Specify how many results to show', default=3)

    # Handle search string
    (opts, args) = parser.parse_args()
    if len(args) < 1:
        print 'You have to at least specify a search string!'
        parser.print_help()
        exit(-1)
    searchstring = ' '.join(args)

    sys.exit(main(opts, searchstring))
